@@ -134,6 +134,8 @@ class Command(BaseCommand):
             staticDict = self.buildFileDict('static')
             staticDict['js/FixTemplate.js'] = \
                 hashlib.md5('js/FixTemplate.js').hexdigest()
+            staticDict['js/Workaround.js'] = \
+                hashlib.md5('js/Workaround.js').hexdigest()
             templateDict = self.buildFileDict('templates')
             fileDict = dict(staticDict)
             fileDict.update(templateDict)
@@ -319,6 +321,11 @@ class Command(BaseCommand):
         if not ele.text:
             ele.text = ''
 
+        if ele.tag == 'p':
+            ele.set('cmsboilerplatetag', 'p')
+            comment = etree.Comment('cmsboilerplatetag=p')
+            ele.addnext(comment)
+
         if ele.getchildren():
             if ele[-1].tail is None:
                 ele[-1].tail = ''
@@ -457,6 +464,10 @@ class Command(BaseCommand):
         addJ.set('src', 'js/FixTemplate.js')
         addJ.tail = '\n'
 
+        addWorkaround = etree.Element('script')
+        addWorkaround.set('src', 'js/Workaround.js')
+        addWorkaround.tail = '\n'
+
         metaDescription = etree.Element('meta')
         metaDescription.set("name", "description")
         metaDescription.set(
@@ -476,6 +487,7 @@ class Command(BaseCommand):
         if createMetaDescription:
             head.insert(0, metaDescription)
         head.insert(0, comment) 
+        head.insert(0, addWorkaround)
         head.insert(0, addJ)
         head.insert(0, jq)
         head.insert(0, cmsData)  
@@ -487,6 +499,12 @@ class Command(BaseCommand):
             head.text = ''
         head.text = '\n' + CMS_HEAD_FRONT_TAG + head.text
 
+        cmsDiv = etree.Element('div')
+        cmsDiv.set("class", "cmsCollection")
+        cmsDiv.tail = '\n'
+
+        body.append(cmsDiv)
+
         # add cms data to body
         if body.getchildren():
             if body[-1].tail is None:
