@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10591 2017-12-03 05:37:16Z Lavender $
+# $Id: create_zip.py 10600 2017-12-04 04:16:19Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-03 13:37:16 +0800 (週日, 03 十二月 2017) $
-# $Revision: 10591 $
+# $Date: 2017-12-04 12:16:19 +0800 (週一, 04 十二月 2017) $
+# $Revision: 10600 $
 
 import os
 import shutil
@@ -98,6 +98,12 @@ class Command(BaseCommand):
             zip = zipfile.ZipFile(
                 os.path.join(ROOT_DIR_PATH, '%s.zip' % templateName), mode='w')
 
+            temp = get_template('boilerplate/js/Workaround.js')
+            content = temp.render()
+            with open(os.path.join(
+                STATIC_DIR_PATH, 'js', 'Workaround.js'), 'wb') as f:
+                f.write(content.encode('utf8'))
+
             logger.info("-----Start copy templates-----")
             for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
                 for f in files:
